# Generalized Kernel Method
We connect [*generalized linear models (GLMs)*](https://en.wikipedia.org/wiki/Generalized_linear_model) with [kernel methods](https://en.wikipedia.org/wiki/Kernel_method) (best known from Support Vector Machines) to obtain a *generalized kernel method*.

## Installation


## Usage


## Theoretical Foundation
